@@ -1,4 +1,4 @@
-test_that("lt.representativity failes for wrong input", {
+test_that("lt.representativity fails for wrong input", {
   expect_snapshot_error(lt.representativity(1))
 })
 
